#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from . import mpfun
from models import *
from utils import *
from sqlalchemy.orm import Session
from database import get_local_db

# 操作日志表

# 加密和HMAC签名
def sign_row(db: Session, row: CzrzEntity) -> None:
    if row.sign != '':
        return
    
    user_id = str(row.user_id) # 用户ID
    user_name = mpfun.enc_data(row.user_name) # 用户账号
    nick_name = mpfun.base64_data(row.nick_name) # 用户昵称
    czrz = mpfun.base64_data(row.czrz) # 操作日志
    gxsj = get_datetime_str(row.gxsj) # 更新时间
    ip = str(row.ip) # IP地址
    action = mpfun.base64_data(row.action) # 动作

    sign_data = ",".join([user_id, user_name, nick_name, czrz, gxsj, ip, action])
    sign_hmac = mpfun.sign_data(sign_data)
    # print('sign_tbl_czrz sign_data:', sign_data)
    # print('sign_tbl_czrz sign_hmac:', sign_hmac)

    row.user_name = user_name
    row.sign = sign_hmac
    
    db.commit()
    
# 比较字段合并字符串是否和MAC值匹配上,调用密码服务器[验证HMAC]接口
def sign_valid_row(row: CzrzEntity) -> bool:
    return True

    if row.sign == '':
        return True

    # 关键字段合并字符串
    sign_data = get_sign_str(row)
    # print('sys_user sign_data:', sign_data)
    
    # 原HMACSM3数值
    sign_hmac = row.sign
    # print('sign_hmac:', sign_hmac)

    return mpfun.hmac_verify(sign_data, sign_hmac)

# 生成待签名的字符串
def get_sign_str(row: CzrzEntity) -> str:
    user_id = str(row.user_id) # 用户ID
    user_name = row.user_name # 用户账号
    nick_name = mpfun.base64_data(row.nick_name) # 用户昵称
    czrz = mpfun.base64_data(row.czrz) # 操作日志
    gxsj = get_datetime_str(row.gxsj) # 更新时间
    ip = str(row.ip) # IP地址
    action = mpfun.base64_data(row.action) # 动作

    # 关键字段合并字符串
    sign_data = ",".join([user_id, user_name, nick_name, czrz, gxsj, ip, action])
    return sign_data

# 生成HAMC签名值
def get_sign_hmac(row: CzrzEntity) -> str:
    sign_data = get_sign_str(row)
    return mpfun.sign_data(sign_data) 

# 对所有数据进行签名
def sign_table():
    print('sign_tp_czrz table =====>>>')
    with get_local_db() as db:
        rows = db.query(CzrzEntity).filter(CzrzEntity.sign == '').all()
        for row in rows:
            sign_row(db, row)


def create_data(begin_time: datetime):
    # create_data1(begin_time)
    # create_data2(begin_time)
    pass
    

def create_data1(begin_time: datetime):
    import random
    from datetime import datetime

    with get_local_db() as db:
        dt = begin_time

        while dt < datetime.now():
            random_hour = random.randint(1, 5)
            random_second = random.randint(1, 3600) 
            dt = dt + timedelta(hours=random_hour)
            dt = dt + timedelta(seconds=random_second)

            r = random_hour % 3
            if r == 0:
                user_id = 1
                user_name = 'admin'
                nick_name = '超级管理员'
            elif r == 1:
                user_id = 3
                user_name = 'test1'
                nick_name = '本部门及以下 密码666666'
            else:
                user_id = 8
                user_name = 'test'
                nick_name = '工作人员测试账号'

            db_entity = CzrzEntity()
            db_entity.user_id = user_id
            db_entity.user_name = user_name
            db_entity.nick_name = nick_name
            db_entity.czrz = '后台管理登录成功' if r < 2 else '后台USBKEY登录成功'
            db_entity.gxsj = dt
            db_entity.ip = '172.26.1.92'
            db_entity.action = '登录'
            db_entity.sign = ''

            print("new log:" + str(dt))

            db.add(db_entity)
            db.commit()
        
def create_data2(begin_time: datetime):
    import random
    from datetime import datetime

    with get_local_db() as db:
        dt = begin_time

        while dt < datetime.now():
            random_hour = random.randint(6, 24)
            random_second = random.randint(1, 3600) 
            dt = dt + timedelta(hours=random_hour)
            dt = dt + timedelta(seconds=random_second)

            r = random_hour % 6
            if r == 0:
                user_id = 1
                user_name = 'admin'
                nick_name = '超级管理员'
                czrz = "创建事件"
            elif r == 1:
                user_id = 1
                user_name = 'admin'
                nick_name = '超级管理员'
                czrz = "大屏登录成功"
            elif r == 3:
                user_id = 1
                user_name = 'admin'
                nick_name = '超级管理员'
                czrz = "启动预案"
            elif r == 4:
                user_id = 7
                user_name = '001'
                nick_name = '领导测试账号'
                czrz = "预案任务下发"
            elif r == 5:
                user_id = 8
                user_name = 'test'
                nick_name = '工作人员测试账号'
                czrz = "发起会议"
            else:
                user_id = 8
                user_name = 'test'
                nick_name = '工作人员测试账号'
                czrz = "任务下达"
            db_entity = CzrzEntity()
            db_entity.user_id = user_id
            db_entity.user_name = user_name
            db_entity.nick_name = nick_name
            db_entity.czrz = czrz
            db_entity.gxsj = dt
            db_entity.ip = '172.26.1.92'
            db_entity.action = '应急一张图'
            db_entity.sign = ''

            print("new log:" + str(dt))

            db.add(db_entity)
            db.commit()
        
