#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from . import mpfun
from models import *
from sqlalchemy.orm import Session
from database import get_local_db

# 三防责任人管理人员信息表

# 加密和HMAC签名
def sign_row(db: Session, row: ThreeProofingResponsiblePerson) -> None:
    if row.sign != '':
        return
    
    unit_id = str(row.unit_id) # 单位ID
    unit_name = mpfun.base64_data(row.unit_name) # 单位名称
    name = mpfun.base64_data(row.name) # 联系人
    position = mpfun.base64_data(row.position) # 职务
    area_code2 = row.area_code2 # 区划编码2
    area_code = str(row.area_code) # 区划编码
    phone = mpfun.enc_data(row.phone) # 手机号码
    telephone = mpfun.enc_data(row.telephone) # 办公电话
    del_flag = row.del_flag # 是否已删除

    sign_data = ",".join([unit_id, unit_name, name, position, area_code2, area_code, phone, telephone, del_flag])
    sign_hmac = mpfun.sign_data(sign_data)
    # print('sign_data:', sign_data)
    # print('sign_hmac:', sign_hmac)

    row.phone = phone
    row.telephone = telephone
    row.sign = sign_hmac
    
    db.commit()

# 比较字段合并字符串是否和MAC值匹配上,调用密码服务器[验证HMAC]接口
def sign_valid_row(row: ThreeProofingResponsiblePerson) -> bool:
    return True

    if row.sign == '':
        return True

    # 关键字段合并字符串
    sign_data = get_sign_str(row)
    # print('sys_user sign_data:', sign_data)
    
    # 原HMACSM3数值
    sign_hmac = row.sign
    # print('sign_hmac:', sign_hmac)

    return mpfun.hmac_verify(sign_data, sign_hmac)

# 生成待签名的字符串
def get_sign_str(row: ThreeProofingResponsiblePerson) -> str:
    unit_id = str(row.unit_id) # 单位ID
    unit_name = mpfun.base64_data(row.unit_name) # 单位名称
    name = mpfun.base64_data(row.name) # 联系人
    position = mpfun.base64_data(row.position) # 职务
    area_code2 = row.area_code2 # 区划编码2
    area_code = str(row.area_code) # 区划编码
    phone = (row.phone) # 手机号码
    telephone = (row.telephone) # 办公电话
    del_flag = row.del_flag # 是否已删除

    # 关键字段合并字符串
    sign_data = ",".join([unit_id, unit_name, name, position, area_code2, area_code, phone, telephone, del_flag])
    return sign_data

# 生成HAMC签名值
def get_sign_hmac(row: ThreeProofingResponsiblePerson) -> str:
    sign_data = get_sign_str(row)
    return mpfun.sign_data(sign_data) 

# 对所有数据进行签名
def sign_table():
    print('sign_three_proofing_responsible_person table =====>>>')
    with get_local_db() as db:
        rows = db.query(ThreeProofingResponsiblePerson).filter(ThreeProofingResponsiblePerson.sign == '').all()
        for row in rows:
            sign_row(db, row)