# -*- coding: utf-8 -*-
from sqlalchemy import String, Column, Integer, DateTime,Text,BigInteger,Float,Date
from sqlalchemy.dialects.mysql import TINYINT
from sqlalchemy.sql import func
from database import Base
from datetime import datetime

# 危化企业信息表
class ChemicalCompany(Base):
    __tablename__ = 'chemical_company'

    id = Column(BigInteger, primary_key=True,autoincrement=True, comment='主键')
    province = Column(String, default='', comment='省')
    city = Column(String, default='', comment='地市')
    area = Column(String, default='', comment='区县')
    company_name = Column(String, default='', comment='企业名称')
    company_code = Column(String, default='', comment='企业编码')
    company_type = Column(String, default='', comment='企业类型')
    is_import = Column(String, default='', comment='是否涉及进口')
    is_manage = Column(String, default='', comment='是否涉及经营')
    registration_date = Column(String, default='', comment='工商注册时间')
    registration_address = Column(String, default='', comment='工商注册地址')
    credit_code = Column(String, default='', comment='统一社会信用代码')
    industry_classification = Column(String, default='', comment='行业分类')
    production_scale = Column(Text, default='', comment='主要产品及生产规模')
    chemical_park_location = Column(String, default='', comment='所在化工园区')
    emergency_contact_number = Column(String, default='', comment='安全值班电话')
    emergency_response_hotline = Column(String, default='', comment='应急咨询服务电话')
    qyagjgfzr_phone = Column(String, default='', comment='企业安管机构负责人手机号')
    qyfgaqfzr_phone = Column(String, default='', comment='企业分管安全负责人手机号')
    sfqdwxhxpaqscxkz = Column(String, default='', comment='是否取得危险化学品安全生产许可证')
    xkzbh = Column(String, default='', comment='许可证编号')
    sfqdwxhxpjyxkz = Column(String, default='', comment='是否取得危险化学品经营许可证')
    sfqdwxhxpsyxkz = Column(String, default='', comment='是否取得危险化学品使用许可证')
    factory_address = Column(String, default='', comment='厂区地址')
    hazard_source = Column(Text, default='', comment='重大危险源')
    hazardous_chemical_process = Column(Text, default='', comment='危险化工工艺')
    issuance_date = Column(String, default='', comment='发证日期')
    certificate_expiry_date = Column(String, default='', comment='证书有效期')
    company_registration_number = Column(String, default='', comment='企业登记证编码')
    number_of_employees = Column(Integer, default='0', comment='职工人数')
    deregistration_date = Column(String, default='', comment='注销时间')
    scale_of_enterprise = Column(String, default='', comment='企业规模')
    chemical_industry_classification = Column(String, default='', comment='化工行业分类')
    safe_level = Column(String, default='', comment='安全标准化等级')
    priority = Column(String, default='', comment='重点行业')
    longitude = Column(Float, comment='经度')
    latitude = Column(Float, comment='纬度')
    formatted_address = Column(String, default='', comment='地址')
    s_last_updatetime = Column(DateTime, comment='更新时间')
    sign = Column(String, server_default='', default='', comment='HMACSM3数值')

    class Config:
        orm_mode = True


# 建筑工程信息表
class BuildingProjectInfo(Base):
    __tablename__ = 'building_project_info'

    id = Column(BigInteger, primary_key=True,autoincrement=True, comment='主键')
    prjcode = Column(String, default='', comment='项目编号')
    prjname = Column(String, default='', comment='项目名称')
    prjnum = Column(String, default='', comment='投资项目在线审批监管平台统一项目代码')
    letternum = Column(String, default='', comment='立项文号')
    prjlevel = Column(String, default='', comment='立项级别')
    issueby = Column(String, default='', comment='立项批复机关')
    dtissue = Column(DateTime, comment='立项批复时间')
    prjtypename = Column(String, default='', comment='项目类型')
    cityid = Column(String, default='', comment='项目所在地区编码（地市）')
    cityname = Column(String, default='', comment='项目所在地区名称（地市）')
    countyid = Column(Integer, comment='项目所在地区编码（县区）')
    countyname = Column(String, default='', comment='项目所在地区名称（县区）')
    address = Column(String, default='', comment='项目地址')
    longitude = Column(Float, comment='经度')
    latitude = Column(String, comment='纬度')
    prjsizedes = Column(String, default='', comment='建设规模')
    allinvest = Column(Float, default='', comment='总投资（万元）')
    allarea = Column(Float, comment='总面积（平方米）')
    alllength = Column(Float, comment='总长度（米）')
    allspan = Column(Float, comment='总跨度（米）')
    prjpropertyname = Column(String, default='', comment='建设性质')
    prjusefor = Column(String, default='', comment='工程用途')
    dtplans = Column(DateTime, comment='计划开工日期')
    dtplane = Column(DateTime, comment='计划竣工日期')
    ownername = Column(String, default='', comment='建设单位')
    ownerid = Column(String, default='', comment='建设单位统一信用代码（或个人身份证号码）')
    zjlygjzfczzjtz = Column(Float, comment='资金来源-各级政府财政资金投资')
    zjlygyqyzjtz = Column(Float, comment='资金来源-国有企业资金投资')
    zjlygjrz = Column(Float, comment='资金来源-国家融资')
    zjlysygjzzhzwgzfzj = Column(Float, comment='资金来源-使用国际组织或外国政府资金')
    zjlyjtjjzztz = Column(Float, comment='资金来源-集体经济组织投资')
    zjlywstz = Column(Float, comment='资金来源-外商（国）投资')
    zjlyggttz = Column(Float, comment='资金来源-港澳台投资')
    zjlysytz = Column(Float, comment='资金来源-私（民）营投资')
    zjlyqtzjly = Column(Float, comment='资金来源-其他资金来源')
    add_time = Column(DateTime, comment='新增时间')
    cd_time = Column(DateTime, comment='增量时间')
    cd_operation = Column(String, default='', comment='增量标识')
    cd_batch = Column(String, default='', comment='批次号')
    sign = Column(String, server_default='', default='', comment='HMACSM3数值')
    class Config:
        orm_mode = True


class EmergencyExpertInfo(Base):
    __tablename__ = 'emergency_expert_info'

    id = Column(Integer, primary_key=True, autoincrement=True, comment='序号')
    name = Column(String(255), nullable=False, comment='姓名')
    county = Column(String(255), comment='所属区县')
    expert_type = Column(String(255), comment='专家类型')
    honorary_title = Column(String(255), comment='荣誉称号')
    unit = Column(String(255), comment='单位')
    position = Column(String(255), comment='职位')
    professional_title = Column(String(255), comment='职称')
    specialty = Column(String(255), comment='擅长事故类型')
    rescue_experience = Column(Text, comment='救援经历')
    birth_date = Column(Date, comment='出生日期')
    work_start_date = Column(Date, comment='工作时间')
    certificate_issue_date = Column(Date, comment='发证日期')
    professional_group = Column(String(255), comment='专业分组')
    professional_field = Column(String(255), comment='专业领域')
    work_phone = Column(String(20), comment='工作电话')
    home_phone = Column(String(20), comment='住宅电话')
    mobile_phone = Column(String(20), comment='移动电话')
    email = Column(String(255), comment='电子邮箱')
    contact_address = Column(String(255), comment='联系地址')
    longitude = Column(Float, comment='经度')
    latitude = Column(Float, comment='纬度')